@@ -7,5 +7,5 @@ heroes = {
     'mccree': '0x02E0000000000042', 'junkrat': '0x02E0000000000065', 'zarya': '0x02E0000000000068',
     'soldier:76': '0x02E000000000006E', 'lucio': '0x02E0000000000079', 'dva': '0x02E000000000007A',
     'mei': '0x02E00000000000DD', 'sombra': '0x02E000000000012E', 'doomfist': '0x02E000000000012F',
-    'ana': '0x02E000000000013B', 'orisa': '0x02E000000000013E'
+    'ana': '0x02E000000000013B', 'orisa': '0x02E000000000013E', 'moira' : '0x02E00000000001A2'
 }
\ No newline at end of file
